## 通达信板块行情

接口：tdx_daily

描述：获取通达信各板块行情，包括成交和估值等数据

限量：单次提取最大3000条数据，可根据板块代码和日期参数循环提取

权限：用户积累6000积分可调取，具体请参阅积分获取办法

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 板块代码：xxxxxx.TDX |
| trade_date | str | N | 交易日期，格式YYYYMMDD,下同 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | 板块代码 |
| trade_date | str | Y | 交易日期 |
| close | float | Y | 收盘点位 |
| open | float | Y | 开盘点位 |
| high | float | Y | 最高点位 |
| low | float | Y | 最低点位 |
| pre_close | float | Y | 昨日收盘点 |
| change | float | Y | 涨跌点位 |
| pct_change | float | Y | 涨跌幅% |
| vol | float | Y | 成交量 |
| amount | float | Y | 成交额, 对于期货指数，该字段存储持仓量 |
| rise | str | Y | 收盘涨速% |
| vol_ratio | float | Y | 量比 |
| turnover_rate | float | Y | 换手% |
| swing | float | Y | 振幅% |
| up_num | int | Y | 上涨家数 |
| down_num | int | Y | 下跌家数 |
| limit_up_num | int | Y | 涨停家数 |
| limit_down_num | int | Y | 跌停家数 |
| lu_days | int | Y | 连涨天数 |
| 3day | float | Y | 3日涨幅% |
| 5day | float | Y | 5日涨幅% |
| 10day | float | Y | 10日涨幅% |
| 20day | float | Y | 20日涨幅% |
| 60day | float | Y | 60日涨幅% |
| mtd | float | Y | 月初至今% |
| ytd | float | Y | 年初至今% |
| 1year | float | Y | 一年涨幅% |
| pe | str | Y | 市盈率 |
| pb | str | Y | 市净率 |
| float_mv | float | Y | 流通市值(亿) |
| ab_total_mv | float | Y | AB股总市值（亿） |
| float_share | float | Y | 流通股(亿) |
| total_share | float | Y | 总股本(亿) |
| bm_buy_net | float | Y | 主买净额(元) |
| bm_buy_ratio | float | Y | 主买占比% |
| bm_net | float | Y | 主力净额 |
| bm_ratio | float | Y | 主力占比% |

接口示例

```python
#获取通达信2025年5月13日概念板块行情
df = pro.tdx_daily(trade_date='20250513')
```

数据示例

```python
ts_code trade_date    close     open     high  ...  total_share  bm_buy_net  bm_buy_ratio     bm_net  bm_ratio
0    880559.TDX   20250513  4344.82  4243.64  4377.61  ...        63.92    -3711.74         -5.99    3460.16      5.58
```